==> ec2-0.29.0-sources.jar: software/amazon/awscdk/services/ec2/SecurityGroupImportProps.java <==
package software.amazon.awscdk.services.ec2;

@javax.annotation.Generated(value = "jsii-pacmak/0.10.3 (build 6bbf743)", date = "2019-04-24T21:03:46.725Z")
public interface SecurityGroupImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ID of security group.
     */
    java.lang.String getSecurityGroupId();

    /**
     * @return a {@link Builder} of {@link SecurityGroupImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link SecurityGroupImportProps}
     */
    final class Builder {
        private java.lang.String _securityGroupId;

        /**
         * Sets the value of SecurityGroupId
         * @param value ID of security group.
         * @return {@code this}
         */
        public Builder withSecurityGroupId(final java.lang.String value) {
            this._securityGroupId = java.util.Objects.requireNonNull(value, "securityGroupId is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SecurityGroupImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public SecurityGroupImportProps build() {
            return new SecurityGroupImportProps() {
                private final java.lang.String $securityGroupId = java.util.Objects.requireNonNull(_securityGroupId, "securityGroupId is required");

                @Override
                public java.lang.String getSecurityGroupId() {
                    return this.$securityGroupId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("securityGroupId", om.valueToTree(this.getSecurityGroupId()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.SecurityGroupImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ID of security group.
         */
        @Override
        public java.lang.String getSecurityGroupId() {
            return this.jsiiGet("securityGroupId", java.lang.String.class);
        }
    }
}

==> ec2-0.30.0-sources.jar: software/amazon/awscdk/services/ec2/SecurityGroupImportProps.java <==
package software.amazon.awscdk.services.ec2;

@javax.annotation.Generated(value = "jsii-pacmak/0.10.3 (build 6bbf743)", date = "2019-05-02T10:10:02.018Z")
public interface SecurityGroupImportProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ID of security group.
     */
    java.lang.String getSecurityGroupId();
    /**
     * The VPC ID this security group is part of.
     * 
     * If not provided, the `securityGroupVpcId` property
     * will throw an exception.
     */
    java.lang.String getSecurityGroupVpcId();

    /**
     * @return a {@link Builder} of {@link SecurityGroupImportProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link SecurityGroupImportProps}
     */
    final class Builder {
        private java.lang.String _securityGroupId;
        @javax.annotation.Nullable
        private java.lang.String _securityGroupVpcId;

        /**
         * Sets the value of SecurityGroupId
         * @param value ID of security group.
         * @return {@code this}
         */
        public Builder withSecurityGroupId(final java.lang.String value) {
            this._securityGroupId = java.util.Objects.requireNonNull(value, "securityGroupId is required");
            return this;
        }
        /**
         * Sets the value of SecurityGroupVpcId
         * @param value The VPC ID this security group is part of.
         * @return {@code this}
         */
        public Builder withSecurityGroupVpcId(@javax.annotation.Nullable final java.lang.String value) {
            this._securityGroupVpcId = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SecurityGroupImportProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public SecurityGroupImportProps build() {
            return new SecurityGroupImportProps() {
                private final java.lang.String $securityGroupId = java.util.Objects.requireNonNull(_securityGroupId, "securityGroupId is required");
                @javax.annotation.Nullable
                private final java.lang.String $securityGroupVpcId = _securityGroupVpcId;

                @Override
                public java.lang.String getSecurityGroupId() {
                    return this.$securityGroupId;
                }

                @Override
                public java.lang.String getSecurityGroupVpcId() {
                    return this.$securityGroupVpcId;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("securityGroupId", om.valueToTree(this.getSecurityGroupId()));
                    obj.set("securityGroupVpcId", om.valueToTree(this.getSecurityGroupVpcId()));
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.SecurityGroupImportProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ID of security group.
         */
        @Override
        public java.lang.String getSecurityGroupId() {
            return this.jsiiGet("securityGroupId", java.lang.String.class);
        }

        /**
         * The VPC ID this security group is part of.
         * 
         * If not provided, the `securityGroupVpcId` property
         * will throw an exception.
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.String getSecurityGroupVpcId() {
            return this.jsiiGet("securityGroupVpcId", java.lang.String.class);
        }
    }
}
